#!/usr/bin/python3

# === IMPORTS ===

# === GLOBALS ===

# === FUNCTIONS ===

# === CLASSES ===
class DuplicateException(Exception):
    pass

class ExistsException(Exception):
    pass

class InvalidDataException(Exception):
    pass

class NotExistsException(Exception):
    pass

# === MAIN ===
